[![Version](https://img.shields.io/pypi/v/pybary.svg)](https://pypi.python.org/pypi/pybary)
[![python](https://img.shields.io/pypi/pyversions/pybary.svg)](https://pypi.org/project/pybary/)
[![codecov](https://codecov.io/gh/asmove/pybary/branch/main/graph/badge.svg?token=G8TVJ4X32L)](https://codecov.io/gh/asmove/pybary)
[![downloads](https://img.shields.io/pypi/dm/pybary)](https://pypi.org/project/pybary/)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/asmove/pybary/HEAD)

Pybary
========

![A sniffer optimizer](https://github.com/asmove/pybary/blob/main/images/pybary-tiny.png?raw=true)

Barycenter method in python. Take a look at original article: https://arxiv.org/abs/1801.10533

How to install
----------------

We run the command on desired installation environment:

``` {.bash}
pip install pybary
```

Minimal example
----------------

We may code examples by performing following actions 

1. Run command `python examples/example.py` from package root folder;
2. Open notebook `examples/example.ipynb` and run cell on given order.
